package com.ibiz5.app.demoapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import com.ibiz5.app.demoapi.dto.*;
import com.ibiz5.app.demoapi.mapping.*;
import com.ibiz5.app.core.sample.domain.IBZ5Customer_INTF;
import com.ibiz5.app.core.sample.service.IIBZ5Customer_INTFService;
import com.ibiz5.app.core.sample.filter.IBZ5Customer_INTFSearchContext;
import com.ibiz5.app.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"客户" })
@RestController("DemoAPI-ibz5customer_intf")
@RequestMapping("")
public class IBZ5Customer_INTFResource {

    @Autowired
    public IIBZ5Customer_INTFService ibz5customer_intfService;

    @Autowired
    @Lazy
    public IBZ5Customer_INTFMapping ibz5customer_intfMapping;

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Customer_INTF-searchCurCustomer-all') and hasPermission(#context,'DemoSys-IBZ5Customer_INTF-Get')")
	@ApiOperation(value = "获取CurCustomer", tags = {"客户" } ,notes = "获取CurCustomer")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5customer_intfs/fetchcurcustomer")
	public ResponseEntity<List<IBZ5Customer_INTFDTO>> fetchCurCustomer(IBZ5Customer_INTFSearchContext context) {
        Page<IBZ5Customer_INTF> domains = ibz5customer_intfService.searchCurCustomer(context) ;
        List<IBZ5Customer_INTFDTO> list = ibz5customer_intfMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Customer_INTF-searchCurCustomer-all') and hasPermission(#context,'DemoSys-IBZ5Customer_INTF-Get')")
	@ApiOperation(value = "查询CurCustomer", tags = {"客户" } ,notes = "查询CurCustomer")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5customer_intfs/searchcurcustomer")
	public ResponseEntity<Page<IBZ5Customer_INTFDTO>> searchCurCustomer(@RequestBody IBZ5Customer_INTFSearchContext context) {
        Page<IBZ5Customer_INTF> domains = ibz5customer_intfService.searchCurCustomer(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5customer_intfMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PostAuthorize("hasPermission(this.ibz5customer_intfMapping.toDomain(returnObject.body),'DemoSys-IBZ5Customer_INTF-Get')")
    @ApiOperation(value = "获取客户", tags = {"客户" },  notes = "获取客户")
	@RequestMapping(method = RequestMethod.GET, value = "/ibz5customer_intfs/{ibz5customer_intf_id}")
    public ResponseEntity<IBZ5Customer_INTFDTO> get(@PathVariable("ibz5customer_intf_id") String ibz5customer_intf_id) {
        IBZ5Customer_INTF domain = ibz5customer_intfService.get(ibz5customer_intf_id);
        IBZ5Customer_INTFDTO dto = ibz5customer_intfMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.ibz5customer_intfMapping.toDomain(#ibz5customer_intfdto),'DemoSys-IBZ5Customer_INTF-Create')")
    @ApiOperation(value = "新建客户", tags = {"客户" },  notes = "新建客户")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5customer_intfs")
    public ResponseEntity<IBZ5Customer_INTFDTO> create(@Validated @RequestBody IBZ5Customer_INTFDTO ibz5customer_intfdto) {
        IBZ5Customer_INTF domain = ibz5customer_intfMapping.toDomain(ibz5customer_intfdto);
		ibz5customer_intfService.create(domain);
        IBZ5Customer_INTFDTO dto = ibz5customer_intfMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.ibz5customer_intfMapping.toDomain(#ibz5customer_intfdtos),'DemoSys-IBZ5Customer_INTF-Create')")
    @ApiOperation(value = "批量新建客户", tags = {"客户" },  notes = "批量新建客户")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5customer_intfs/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<IBZ5Customer_INTFDTO> ibz5customer_intfdtos) {
        ibz5customer_intfService.createBatch(ibz5customer_intfMapping.toDomain(ibz5customer_intfdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "ibz5customer_intf" , versionfield = "updatedate")
    @PreAuthorize("hasPermission(this.ibz5customer_intfService.get(#ibz5customer_intf_id),'DemoSys-IBZ5Customer_INTF-Update')")
    @ApiOperation(value = "更新客户", tags = {"客户" },  notes = "更新客户")
	@RequestMapping(method = RequestMethod.PUT, value = "/ibz5customer_intfs/{ibz5customer_intf_id}")
    public ResponseEntity<IBZ5Customer_INTFDTO> update(@PathVariable("ibz5customer_intf_id") String ibz5customer_intf_id, @RequestBody IBZ5Customer_INTFDTO ibz5customer_intfdto) {
		IBZ5Customer_INTF domain  = ibz5customer_intfMapping.toDomain(ibz5customer_intfdto);
        domain .setIbz5customerid(ibz5customer_intf_id);
		ibz5customer_intfService.update(domain );
		IBZ5Customer_INTFDTO dto = ibz5customer_intfMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.ibz5customer_intfService.getIbz5customerIntfByEntities(this.ibz5customer_intfMapping.toDomain(#ibz5customer_intfdtos)),'DemoSys-IBZ5Customer_INTF-Update')")
    @ApiOperation(value = "批量更新客户", tags = {"客户" },  notes = "批量更新客户")
	@RequestMapping(method = RequestMethod.PUT, value = "/ibz5customer_intfs/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<IBZ5Customer_INTFDTO> ibz5customer_intfdtos) {
        ibz5customer_intfService.updateBatch(ibz5customer_intfMapping.toDomain(ibz5customer_intfdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.ibz5customer_intfService.get(#ibz5customer_intf_id),'DemoSys-IBZ5Customer_INTF-Remove')")
    @ApiOperation(value = "删除客户", tags = {"客户" },  notes = "删除客户")
	@RequestMapping(method = RequestMethod.DELETE, value = "/ibz5customer_intfs/{ibz5customer_intf_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("ibz5customer_intf_id") String ibz5customer_intf_id) {
         return ResponseEntity.status(HttpStatus.OK).body(ibz5customer_intfService.remove(ibz5customer_intf_id));
    }

    @PreAuthorize("hasPermission(this.ibz5customer_intfService.getIbz5customerIntfByIds(#ids),'DemoSys-IBZ5Customer_INTF-Remove')")
    @ApiOperation(value = "批量删除客户", tags = {"客户" },  notes = "批量删除客户")
	@RequestMapping(method = RequestMethod.DELETE, value = "/ibz5customer_intfs/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        ibz5customer_intfService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "获取客户草稿", tags = {"客户" },  notes = "获取客户草稿")
	@RequestMapping(method = RequestMethod.GET, value = "/ibz5customer_intfs/getdraft")
    public ResponseEntity<IBZ5Customer_INTFDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(ibz5customer_intfMapping.toDto(ibz5customer_intfService.getDraft(new IBZ5Customer_INTF())));
    }

    @ApiOperation(value = "检查客户", tags = {"客户" },  notes = "检查客户")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5customer_intfs/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody IBZ5Customer_INTFDTO ibz5customer_intfdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(ibz5customer_intfService.checkKey(ibz5customer_intfMapping.toDomain(ibz5customer_intfdto)));
    }

    @PreAuthorize("hasPermission(this.ibz5customer_intfMapping.toDomain(#ibz5customer_intfdto),'DemoSys-IBZ5Customer_INTF-Save')")
    @ApiOperation(value = "保存客户", tags = {"客户" },  notes = "保存客户")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5customer_intfs/save")
    public ResponseEntity<Boolean> save(@RequestBody IBZ5Customer_INTFDTO ibz5customer_intfdto) {
        return ResponseEntity.status(HttpStatus.OK).body(ibz5customer_intfService.save(ibz5customer_intfMapping.toDomain(ibz5customer_intfdto)));
    }

    @PreAuthorize("hasPermission(this.ibz5customer_intfMapping.toDomain(#ibz5customer_intfdtos),'DemoSys-IBZ5Customer_INTF-Save')")
    @ApiOperation(value = "批量保存客户", tags = {"客户" },  notes = "批量保存客户")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5customer_intfs/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<IBZ5Customer_INTFDTO> ibz5customer_intfdtos) {
        ibz5customer_intfService.saveBatch(ibz5customer_intfMapping.toDomain(ibz5customer_intfdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Customer_INTF-XXX-all')")
    @ApiOperation(value = "", tags = {"客户" },  notes = "")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5customer_intfs/{ibz5customer_intf_id}/xxx")
    public ResponseEntity<IBZ5Customer_INTFDTO> xXX(@PathVariable("ibz5customer_intf_id") String ibz5customer_intf_id, @RequestBody IBZ5Customer_INTFDTO ibz5customer_intfdto) {
        IBZ5Customer_INTF domain = ibz5customer_intfMapping.toDomain(ibz5customer_intfdto);
        domain.setIbz5customerid(ibz5customer_intf_id);
        domain = ibz5customer_intfService.xXX(domain);
        ibz5customer_intfdto = ibz5customer_intfMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5customer_intfdto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Customer_INTF-searchDefault-all') and hasPermission(#context,'DemoSys-IBZ5Customer_INTF-Get')")
	@ApiOperation(value = "获取DEFAULT", tags = {"客户" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5customer_intfs/fetchdefault")
	public ResponseEntity<List<IBZ5Customer_INTFDTO>> fetchDefault(IBZ5Customer_INTFSearchContext context) {
        Page<IBZ5Customer_INTF> domains = ibz5customer_intfService.searchDefault(context) ;
        List<IBZ5Customer_INTFDTO> list = ibz5customer_intfMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Customer_INTF-searchDefault-all') and hasPermission(#context,'DemoSys-IBZ5Customer_INTF-Get')")
	@ApiOperation(value = "查询DEFAULT", tags = {"客户" } ,notes = "查询DEFAULT")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5customer_intfs/searchdefault")
	public ResponseEntity<Page<IBZ5Customer_INTFDTO>> searchDefault(@RequestBody IBZ5Customer_INTFSearchContext context) {
        Page<IBZ5Customer_INTF> domains = ibz5customer_intfService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5customer_intfMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


}

